# Fermi Contours

[![PyPI](https://img.shields.io/pypi/v/fermi-contours.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/fermi-contours.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/fermi-contours)][pypi status]
[![License](https://img.shields.io/pypi/l/fermi-contours)][license]

[![Read the documentation at https://fermi-contours.readthedocs.io/](https://img.shields.io/readthedocs/fermi-contours/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/piskunow/fermi-contours/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/piskunow/fermi-contours/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/fermi-contours/
[read the docs]: https://fermi-contours.readthedocs.io/
[tests]: https://github.com/piskunow/fermi-contours/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/piskunow/fermi-contours
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

## Reference

Code adapted from

Perez-Piskunow, Pablo M, Bovenzi, Nicandro, Akhmerov, Anton R, & Breitkreiz, Maxim. (2021).
Code and data associated with the paper
"Chiral Anomaly Trapped in Weyl Metals: Nonequilibrium Valley Polarization at
Zero Magnetic Field"
(1.0.1). Zenodo.
[https://doi.org/10.5281/zenodo.4704325](https://doi.org/10.5281/zenodo.4704325)

and extended to take into account periodic boundaries and other edge-cases.

## Requirements

- Python >=3.9

## Installation

You can install _Fermi Contours_ via [pip] from [PyPI]:

```console
$ pip install fermi-contours
```

## Usage

Please see the [Command-line Reference] for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
_Fermi Contours_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project was generated from [@cjolowicz]'s [Hypermodern Python Cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz
[pypi]: https://pypi.org/
[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[file an issue]: https://github.com/piskunow/fermi-contours/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/piskunow/fermi-contours/blob/main/LICENSE
[contributor guide]: https://github.com/piskunow/fermi-contours/blob/main/CONTRIBUTING.md
[command-line reference]: https://fermi-contours.readthedocs.io/en/latest/usage.html
